@@ -297,6 +297,20 @@ fn test_heated() {
     assert!(content.body.as_ref().unwrap().contains("I have some good news and some bad news"));
 }
 
+// Check reported issue that RockPaperShotgun does not extract summary
+#[test]
+fn test_rockpapershotgun() {
+    let test_data = test::fixture_as_raw("rss_2.0_rps.xml");
+    let feed = parser::parse(test_data.as_slice()).unwrap();
+
+    // Feed should have a description
+    assert!(!feed.description.unwrap().content.is_empty());
+
+    // Entry should too
+    let entry = &feed.entries[0];
+    assert!(!entry.summary.as_ref().unwrap().content.is_empty());
+}
+
 // Verifies that we can handle mixed MediaRSS and itunes/enclosure
 #[test]
 fn test_spiegel() {
@@ -354,6 +368,17 @@ fn test_spiegel() {
     assert_eq!(actual, expected);
 }
 
+// Check that we ignore tags in unknown namespaces
+// In the case of this feed, we ignore googleplay, and don't overwrite the RSS2 image
+#[test]
+fn test_spreaker_ignore_unknown_ns() {
+    let test_data = test::fixture_as_raw("rss_2.0_spreaker.xml");
+    let feed = parser::parse(test_data.as_slice()).unwrap();
+
+    // Feed should have a logo
+    assert!(feed.logo.is_some());
+}
+
 // Verifies that we can handle mixed MediaRSS and itunes/enclosure
 #[test]
 fn test_bbc() {
