@@ -115,7 +115,7 @@ impl<R: BufRead> ElementSource<R> {
                             name,
                             attributes,
                             xml_base: ElementSource::xml_base_fetch(&state),
-                            source: &self,
+                            source: self,
                             depth: state.current_depth,
                         };
                         return Ok(Some(element));
@@ -255,27 +255,22 @@ impl<R: BufRead> SourceState<R> {
             match event {
                 // Start of an element
                 Event::Start(ref e) => {
-                    return Ok(Some(XmlEvent::start(ns, e, &reader)));
+                    return Ok(Some(XmlEvent::start(ns, e, reader)));
                 }
 
                 // End of an element
                 Event::End(ref e) => {
-                    return Ok(Some(XmlEvent::end(e, &reader)));
+                    return Ok(Some(XmlEvent::end(e, reader)));
                 }
 
-                // Text
-                Event::Text(ref t) => {
-                    let event = XmlEvent::text(t, &reader);
+                // Text or CData
+                Event::Text(ref t) | Event::CData(ref t) => {
+                    let event = XmlEvent::text(t, reader);
                     if let Ok(Some(ref _t)) = event {
                         return event;
                     }
                 }
 
-                // CData
-                Event::CData(ref t) => {
-                    return Ok(Some(XmlEvent::text_from_cdata(t, &reader)));
-                }
-
                 // The end of the document
                 Event::Eof => {
                     return Ok(None);
@@ -336,7 +331,7 @@ impl<'a, R: BufRead> Element<'a, R> {
     /// Returns an iterator over children of this element (i.e. descends a level in the hierarchy)
     pub(crate) fn children(&self) -> ElementIter<R> {
         ElementIter {
-            source: &self.source,
+            source: self.source,
             depth: self.depth + 1,
         }
     }
@@ -383,24 +378,30 @@ impl<'a, R: BufRead> Iterator for ElementIter<'a, R> {
 /// Set of automatically recognised namespaces
 #[derive(Debug, PartialEq)]
 pub(crate) enum NS {
-    // http://purl.org/rss/1.0/modules/content/
+    // Namespaces we do not support are treated as this special case, to avoid processing content incorrectly
+    Unknown,
+    // Extensions
     Content,
-    // http://purl.org/dc/elements/1.1/
     DublinCore,
-    // http://search.yahoo.com/mrss/
     MediaRSS,
-    // http://www.itunes.com/dtds/podcast-1.0.dtd
     Itunes,
 }
 
 impl NS {
     fn parse(s: &str) -> Option<NS> {
         match s {
+            // Feed namespaces (Atom, RSS) are mapped on to None, since they are the base NS
+            // This handles documents where it is explicit, and implicit
+            "http://www.w3.org/2005/Atom" | "http://purl.org/rss/1.0/" => None,
+
+            // Extension namespaces
             "http://purl.org/rss/1.0/modules/content/" => Some(NS::Content),
             "http://purl.org/dc/elements/1.1/" => Some(NS::DublinCore),
             "http://search.yahoo.com/mrss/" => Some(NS::MediaRSS),
             "http://www.itunes.com/dtds/podcast-1.0.dtd" => Some(NS::Itunes),
-            _ => None,
+
+            // Everything else is ignored
+            _ => Some(NS::Unknown),
         }
     }
 }
@@ -509,12 +510,6 @@ impl XmlEvent {
             Ok(Some(XmlEvent::Text(text)))
         }
     }
-
-    // Creates a new event corresponding to an XML CData tag
-    fn text_from_cdata<R: BufRead>(text: &BytesText, reader: &Reader<R>) -> XmlEvent {
-        let text = reader.decode(text);
-        XmlEvent::Text(text.into())
-    }
 }
 
 // Appends an element-end to the buffer
